package controller

import (
	"electricity_bill_calc/repository"
	"electricity_bill_calc/response"
	"net/http"

	"github.com/gofiber/fiber/v2"
)

func InitializeRegionHandlers(router *fiber.App) {
	router.Get("/region/:rid", getSubRegions)
	router.Get("/regions/:rid", getParentRegions)
}

func getSubRegions(c *fiber.Ctx) error {
	result := response.NewResult(c)
	requestParentId := c.Params("rid")
	regions, err := repository.RegionRepository.FindSubRegions(requestParentId)
	if err != nil {
		return result.Error(http.StatusInternalServerError, err.Error())
	}
	if len(regions) == 0 {
		return result.Json(http.StatusNotFound, "未能获取到相关的行政区划。", fiber.Map{"regions": make([]string, 0)})
	}
	return result.Json(http.StatusOK, "已经获取到相关的行政区划。", fiber.Map{"regions": regions})
}

func getParentRegions(c *fiber.Ctx) error {
	result := response.NewResult(c)
	requestRegionCode := c.Params("rid")
	regions, err := repository.RegionRepository.FindParentRegions(requestRegionCode)
	if err != nil {
		return result.Error(http.StatusInternalServerError, err.Error())
	}
	if len(regions) == 0 {
		return result.Json(http.StatusNotFound, "未能获取到相关的行政区划。", fiber.Map{"regions": make([]string, 0)})
	}
	return result.Json(http.StatusOK, "以及获取到相关的行政区划。", fiber.Map{"regions": regions})
}
